An example program that uses a Wifly module to send messages over web sockets

Dependencies:   WebSocketClient WiflyInterface mbed LM75B MMA7660

Fork of Websocket_Wifly_HelloWorld by Samuel Mokrani

Revision:
1:31e50fea8be8
Parent:
0:64c683256184
Child:
3:d1d4b7d317d1
--- a/main.cpp	Fri Aug 17 12:01:03 2012 +0000
+++ b/main.cpp	Thu Aug 23 14:09:06 2012 +0000
@@ -1,28 +1,28 @@
-#include "mbed.h"
-#include "WiflyInterface.h"
-#include "Websocket.h"
-
-
-/* wifly interface:
-*     - p9 and p10 are for the serial communication
-*     - p25 is for the reset pin
-*     - p26 is for the connection status
-*     - "mbed" is the ssid of the network
-*     - "password" is the password
-*     - true means that the security of the network is WPA
-*/
-WiflyInterface wifly(p9, p10, p25, p26, "mbed", "password", true);
-
-int main() {
-    wifly.init(); //Use DHCP
-    while (!wifly.connect());
-    printf("IP Address is %s\n\r", wifly.getIPAddress());
-
-    Websocket ws("ws://sockets.mbed.org:443/ws/demo/wo");
-    while (!ws.connect());
-
-    while (1) {
-            ws.send("WebSocket Hello World over Wifly");
-            wait(1.0);
-    }
+#include "mbed.h"
+#include "WiflyInterface.h"
+#include "Websocket.h"
+
+
+/* wifly interface:
+*     - p9 and p10 are for the serial communication
+*     - p19 is for the reset pin
+*     - p26 is for the connection status
+*     - "mbed" is the ssid of the network
+*     - "password" is the password
+*     - WPA is the security
+*/
+WiflyInterface wifly(p9, p10, p19, p26, "mbed", "password", WPA);
+
+int main() {
+    wifly.init(); //Use DHCP
+    while (!wifly.connect());
+    printf("IP Address is %s\n\r", wifly.getIPAddress());
+
+    Websocket ws("ws://sockets.mbed.org:443/ws/demo/wo");
+    while (!ws.connect());
+
+    while (1) {
+            ws.send("WebSocket Hello World over Wifly");
+            wait(1.0);
+    }
 }
\ No newline at end of file